@@ -1265,6 +1265,9 @@ LIMBO.process = function(obj){
     obj.find('.date input').datepicker();
     obj.find('.datepicker').datepicker();
     obj.find('.timepicker').timepicker();
+    if ($.fn.dialogbox != undefined){
+        obj.find('.dialog-box').dialogbox();
+    }
     obj.find('.autoresize').autoResize().addClass('ui-widget').addClass('ui-widget-content');
     obj.find('.autocomplete select').combobox();
     obj.find('select.combobox').combobox();
@@ -1629,16 +1632,18 @@ $(function(){
     LIMBO.server_tables = new Object();
     LIMBO.help_dialog = new HelpDialog();
     LIMBO.paginators = new Paginators();
-    $('#user_info').fgmenu({
-        content: $('#user_menu').html(),
-        positionOpts: {
-            posX: 'left',
-            posY: 'bottom',
-            offsetY:2,
-            directionH:'left'},
-        showSpeed: 300,
-        linkToFront: true
-    });
+    if ( $.fn.fgmenu != undefined && $('#user_info').length > 0){
+        $('#user_info').fgmenu({
+            content: $('#user_menu').html(),
+            positionOpts: {
+                posX: 'left',
+                posY: 'bottom',
+                offsetY:2,
+                directionH:'left'},
+            showSpeed: 300,
+            linkToFront: true
+        });
+    }
     LIMBO.messages = new Messages();
     LIMBO.forms = new Forms();
     LIMBO.buttons = new Buttons();
